@@ -31,9 +31,14 @@ import uuid
 from pathlib import Path
 
 from htmlgen_mcp.agents.smart_web_agent import SmartWebAgent
+from htmlgen_mcp.nas_storage import get_nas_storage
+from htmlgen_mcp.nas_log_manager import get_nas_log_manager, ensure_job_log, log_progress, query_progress
+from datetime import datetime
 
+# 使用 NAS 作为默认存储路径
+NAS_PATH = os.environ.get("NAS_STORAGE_PATH", "/app/mcp-servers/mcp-servers/html_agent")
 DEFAULT_PROJECT_ROOT = os.path.abspath(
-    os.environ.get("WEB_AGENT_PROJECT_ROOT", os.path.join(PROJECT_ROOT, "projects"))
+    os.environ.get("WEB_AGENT_PROJECT_ROOT", f"{NAS_PATH}/projects")
 )
 DEFAULT_MODEL = os.environ.get("WEB_AGENT_MODEL", "qwen3-coder-plus-2025-09-23")
 DEFAULT_BASE_URL = os.environ.get(
@@ -42,45 +47,26 @@ DEFAULT_BASE_URL = os.environ.get(
 
 mcp = FastMCP("smart-web-agent")
 
-# MCP 服务持久化目录：优先使用项目根目录下的 .mcp_state，可通过环境变量覆盖
-DEFAULT_MCP_STORAGE = Path.home() / ".mcp"
+# MCP 服务持久化目录：使用 NAS 路径以便集群共享
 MCP_SERVICE_NAME = os.environ.get("MCP_SERVICE_NAME", "make_web")
-
-
-def _resolve_mcp_data_root() -> Path:
-    """解析 MCP 数据目录，优先使用共享项目目录"""
-    env_dir = os.environ.get("MCP_DATA_DIR")
-    if env_dir:
-        path = Path(env_dir)
-        path.mkdir(parents=True, exist_ok=True)
-        return path
-
-    shared_dir = Path(DEFAULT_PROJECT_ROOT) / ".mcp_state"
-    try:
-        shared_dir.mkdir(parents=True, exist_ok=True)
-        return shared_dir
-    except Exception:
-        fallback = DEFAULT_MCP_STORAGE / MCP_SERVICE_NAME
-        fallback.mkdir(parents=True, exist_ok=True)
-        print(
-            f"⚠️ 无法在 {shared_dir} 创建 MCP 数据目录，改用 {fallback}",
-            file=sys.stderr,
-        )
-        return fallback
-
-
-MCP_DATA_ROOT = _resolve_mcp_data_root()
+MCP_DATA_ROOT = Path(
+    os.environ.get("MCP_DATA_DIR", f"{NAS_PATH}/mcp_data/{MCP_SERVICE_NAME}")
+)
+MCP_DATA_ROOT.mkdir(parents=True, exist_ok=True)
 
 # 简单的缓存：记录最近一次生成的计划，避免“create_simple_site → execute_plan”时需手动传递
 PLAN_CACHE_DIR = MCP_DATA_ROOT / "plan_cache"
 PLAN_CACHE_DIR.mkdir(exist_ok=True)
 
+# 进度日志目录，存储每个任务的实时进度
 PROGRESS_LOG_DIR = MCP_DATA_ROOT / "progress_logs"
 PROGRESS_LOG_DIR.mkdir(exist_ok=True)
 
+# 任务状态目录，每个任务一个 JSON 文件
 JOB_STATE_DIR = MCP_DATA_ROOT / "jobs" / "state"
 JOB_STATE_DIR.mkdir(parents=True, exist_ok=True)
 
+# 上下文缓存目录
 CONTEXT_CACHE_DIR = MCP_DATA_ROOT / "context_cache"
 CONTEXT_CACHE_DIR.mkdir(exist_ok=True)
 
@@ -102,6 +88,8 @@ def _persist_job_state(job_id: str) -> None:
         return
     job_copy = {k: v for k, v in job.items() if k not in {"agent"}}
     job_copy["updated_at"] = time.time()
+    
+    # 同时保存到本地和 NAS
     path = _job_state_path(job_id)
     try:
         path.write_text(
@@ -109,6 +97,15 @@ def _persist_job_state(job_id: str) -> None:
         )
     except Exception:
         pass
+    
+    # 保存到 NAS 日志
+    try:
+        log_manager = get_nas_log_manager()
+        plan_id = job.get("plan_id")
+        log_manager.create_job_log(job_id, plan_id)
+        log_progress(job_id, status="registered", job_info=job_copy)
+    except Exception:
+        pass
 
 
 def _load_job_states() -> None:
@@ -189,6 +186,7 @@ def _build_agent(
     show_code: bool = False,
     verbose: bool = False,
     save_output: bool = False,
+    force_single_page: bool = True,
 ) -> SmartWebAgent:
     return SmartWebAgent(
         project_directory=project_directory,
@@ -196,6 +194,7 @@ def _build_agent(
         show_code=show_code,
         verbose=verbose,
         save_output=save_output,
+        force_single_page=force_single_page,
     )
 
 
@@ -270,12 +269,15 @@ def _execute_plan(
     plan: Dict[str, Any],
     *,
     progress_log_path: Optional[str] = None,
+    job_id: Optional[str] = None,
 ) -> Dict[str, Any]:
     progress_events: list[Dict[str, Any]] = []
 
     def _collect(event: Dict[str, Any]) -> None:
         if isinstance(event, dict):
             progress_events.append(event)
+            
+            # 写入本地日志
             if progress_log_path:
                 try:
                     log_record = dict(event)
@@ -285,6 +287,13 @@ def _execute_plan(
                         log_file.write("\n")
                 except Exception:
                     pass
+            
+            # 同时写入 NAS 日志
+            if job_id:
+                try:
+                    log_progress(job_id, **event)
+                except Exception:
+                    pass
 
     results = agent._execute_plan_with_recovery(
         plan,
@@ -764,6 +773,7 @@ async def create_simple_site(
             model=used_model,
             show_code=False,
             verbose=False,
+            force_single_page=True,
         )
 
         # 构建针对简单网站的提示，包含上下文和图片要求
